<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "DTD/xhtml1-strict.dtd">
<html xmlns:t="http://twistedmatrix.com/ns/twisted.web.template/0.1">
  <head>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    <title>Docstrings with Formatting Problems.</title>
    <link href="apidocs.css" type="text/css" rel="stylesheet" />
  </head>
  <body>
    <h1>Docstrings with Formatting Problems.</h1>
    <ul>
      <li t:render="problemObjects">
        <t:slot name="link" />
      </li>
    </ul>
  </body>
</html>
